@@ -41,6 +41,7 @@ class MainWindow(QtWidgets.QMainWindow):
         self.central_widget = CentralWidget(self.rd, parent=self)
         self.project_loaded.connect(self.central_widget.activate)
         self.setCentralWidget(self.central_widget)
+        self.central_widget.init_ui()
 
         # read cache and try to load the last active project
         if self.rd.cache.last_inspection_file:
@@ -172,24 +173,25 @@ class CentralWidget(QtWidgets.QWidget):
         self.setLayout(self.layout)
 
         # add a widget for the data viewer
-        self.data_viewer = DataViewer(self.rd, parent=self)
+        self.data_viewer = DataViewer(self.rd, cfg=self.rd.config.viewer, plugins=self.rd.config.plugins, parent=self)
         self.layout.addWidget(self.data_viewer, 1, 1, 3, 1)
 
         # add a widget for the control panel
-        self.control_panel = ControlPanel(self.rd, parent=self)
+        self.control_panel = ControlPanel(self.rd, cfg=self.rd.config.control_panel, parent=self)
         self.layout.addWidget(self.control_panel, 1, 2, 1, 1)
 
         # add a widget for displaying information about the object
-        self.object_info = ObjectInfo(self.rd, parent=self)
+        self.object_info = ObjectInfo(self.rd, cfg=self.rd.config.object_info, parent=self)
         self.layout.addWidget(self.object_info, 2, 2, 1, 1)
 
         # add a widget for writing comments
-        self.review_form = ReviewForm(self.rd, parent=self)
+        self.review_form = ReviewForm(self.rd, cfg=self.rd.config.review_form, parent=self)
         self.layout.addWidget(self.review_form, 3, 2, 1, 1)
 
         # connect signals from the control panel to the slots of the central widget
         self.control_panel.object_selected.connect(self.load_object)
         self.control_panel.reset_button_clicked.connect(self.data_viewer.reset_view)
+        self.control_panel.screenshot_button_clicked.connect(self.data_viewer.take_screenshot)
 
     @property
     def widgets(self) -> list[AbstractWidget]:
@@ -198,6 +200,10 @@ class CentralWidget(QtWidgets.QWidget):
         """
         return get_widgets(self.layout)
 
+    def init_ui(self):
+        for widget in self.widgets:
+            widget.init_ui()
+
     @Slot(int)
     def load_object(self, j: int):
         """ Load a new object to the central widget.
@@ -205,8 +211,7 @@ class CentralWidget(QtWidgets.QWidget):
         """
         if self.rd.j is not None:
             # update the application data from widgets
-            for widget in self.widgets:
-                widget.dump()
+            self.review_form.dump()
 
             self.rd.save()  # auto-save
 
@@ -222,10 +227,10 @@ class CentralWidget(QtWidgets.QWidget):
 
     @Slot()
     def activate(self):
-        """ Load a project to the central widget.
+        """ Activate the central widget.
         """
         for widget in self.widgets:
-            widget.load_project()
+            widget.activate()
 
         # cache the inspection file name
         self.rd.cache.last_inspection_file = str(self.rd.output_path)
