@@ -54,6 +54,13 @@ class ReviewForm(AbstractWidget):
 @dataclass
 class ViewerElement(AbstractWidget):
     search_mask: str
+    link: str | None
+
+
+@dataclass
+class Image(ViewerElement):
+    rotate: int | None
+    scale: float | None
 
 
 @dataclass
@@ -65,15 +72,14 @@ class Slider:
 
 
 @dataclass
-class Spec1D(ViewerElement):
+class Spectrum(ViewerElement):
     slider: Slider
 
 
 @dataclass
 class Viewer(AbstractWidget):
-    image_cutout: ViewerElement
-    spec_2d: ViewerElement
-    spec_1d: Spec1D
+    images: dict[str, Image]
+    spectra: dict[str, Spectrum]
 
 
 @dataclass
@@ -85,7 +91,4 @@ class Config(Params):
     object_info: ObjectInfo
     review_form: ReviewForm
     viewer: Viewer
-
-    @classmethod
-    def read(cls, file: LocalFile, path_to_default: str | None = None):
-        return super().read(file, path_to_default='default_config.yml')
+    plugins: list[str]
