@@ -1,14 +1,18 @@
+import abc
+from abc import ABC
+
 from qtpy import QtWidgets
 
-from ..runtime.appdata import AppData
 from ..runtime import config
 from ..utils.widgets import get_widgets
 
 
-class AbstractWidget(QtWidgets.QWidget):
-    def __init__(self, rd: AppData, cfg: config.AbstractWidget, parent=None):
-        self.rd = rd
+class QtAbcMeta(type(QtWidgets.QWidget), type(ABC)):
+    pass
 
+
+class AbstractWidget(QtWidgets.QWidget, ABC, metaclass=QtAbcMeta):
+    def __init__(self, cfg: config.AbstractWidget, parent=None):
         super().__init__(parent)
 
         if cfg.min_width:
@@ -21,28 +25,19 @@ class AbstractWidget(QtWidgets.QWidget):
 
         self.setEnabled(False)
 
-    @property
-    def widgets(self) -> list[QtWidgets.QWidget]:
-        """
-        @return: a list of widgets added to the instance of the AbstractWidget class.
-        """
-        return get_widgets(self.layout)
-
-    def clear_layout(self):
-        for widget in self.widgets:
-            self.layout.removeWidget(widget)
-            widget.destroy()
-
+    @abc.abstractmethod
     def init_ui(self):
         pass
 
-    def dump(self):
-        pass
-
+    @abc.abstractmethod
     def load_object(self):
         pass
 
-    def load_project(self):
-        self.clear_layout()
+    def reset_layout(self):
+        for widget in get_widgets(self.layout):
+            self.layout.removeWidget(widget)
+            widget.destroy()
         self.init_ui()
+
+    def activate(self):
         self.setEnabled(True)
