@@ -1,6 +1,8 @@
 import logging
 from dataclasses import asdict
 
+from qtpy.QtCore import Signal
+
 import numpy as np
 from astropy.io import fits
 from astropy.utils.decorators import lazyproperty
@@ -13,15 +15,18 @@ from ..utils import SmartSlider
 
 from .ViewerElement import ViewerElement
 from ..runtime.appdata import AppData
+from ..runtime import config
 
 
 logger = logging.getLogger(__name__)
 
 
 class Spec1D(ViewerElement):
-    def __init__(self, rd: AppData, parent=None):
-        self.cfg = rd.config.viewer.spec_1d
-        super().__init__(rd=rd, cfg=self.cfg, parent=parent)
+    def __init__(self, rd: AppData, cfg: config.Spectrum, name: str, parent=None):
+        super().__init__(rd=rd, cfg=cfg, name=name, parent=parent)
+
+        self.cfg = cfg
+        self.name = name
 
         # load the list of spectral lines
         # TODO: move to the application data
@@ -44,7 +49,7 @@ class Spec1D(ViewerElement):
         self._redshift_editor.setMaximumWidth(120)
 
         # set up the plot
-        self._spec_1d = self._spec_1d_widget.addPlot()
+        self._spec_1d = self._spec_1d_widget.addPlot(name=self.name)
         self._label_style = {'color': 'r', 'font-size': '20px'}
 
         # set up the spectral lines
@@ -58,49 +63,36 @@ class Spec1D(ViewerElement):
 
             self._line_artists[line_name] = {'line': line, 'label': label}
 
-        self.init_ui()
-
     def init_ui(self):
-        self.layout.addWidget(self._label, 1, 1)
+        # self.layout.addWidget(self._label, 1, 1)
         self.layout.addWidget(self._spec_1d_widget, 2, 1, 1, 3)
         self.layout.addWidget(self._z_slider, 3, 1, 1, 1)
         self.layout.addWidget(QtWidgets.QLabel('z = ', self), 3, 2, 1, 1)
         self.layout.addWidget(self._redshift_editor, 3, 3, 1, 1)
 
     @lazyproperty
-    def _hdu(self):
-        try:
-            with fits.open(self._filename) as hdul:
-                header, data = hdul[1].header, hdul[1].data
-        except ValueError:
-            logger.warning('1D spectrum not found (object ID: {})'.format(self.rd.id))
-            return
-        else:
-            return header, data
+    def default_xrange(self):
+        return np.nanmin(self._data['wave']), np.nanmax(self._data['wave'])
 
     @lazyproperty
-    def _default_xrange(self):
-        return np.nanmin(self._hdu[1]['wave']), np.nanmax(self._hdu[1]['wave'])
-
-    @lazyproperty
-    def _default_yrange(self):
-        return np.nanmin(self._hdu[1]['flux']), np.nanmax(self._hdu[1]['flux'])
+    def default_yrange(self):
+        return np.nanmin(self._data['flux']), np.nanmax(self._data['flux'])
 
     @lazyproperty
     def _label_height(self):
-        y_min, y_max = self._default_yrange
+        y_min, y_max = self.default_yrange
         return y_min + 0.6 * (y_max - y_min)
 
     def _plot(self):
-        self._spec_1d.plot(self._hdu[1]['wave'], self._hdu[1]['flux'], pen='k')
-        self._spec_1d.plot(self._hdu[1]['wave'], self._hdu[1]['err'], pen='r')
+        self._spec_1d.plot(self._data['wave'], self._data['flux'], pen='k')
+        self._spec_1d.plot(self._data['wave'], self._data['err'], pen='r')
 
         for line_name, line_artist in self._line_artists.items():
             self._spec_1d.addItem(line_artist['line'], ignoreBounds=True)
             self._spec_1d.addItem(line_artist['label'])
 
-        self._spec_1d.setLabel('bottom', self._hdu[0]['TUNIT1'], **self._label_style)
-        self._spec_1d.setLabel('left', self._hdu[0]['TUNIT2'], **self._label_style)
+        self._spec_1d.setLabel('bottom', self._hdu.header['TUNIT1'], **self._label_style)
+        # self._spec_1d.setLabel('left', self._hdu.header['TUNIT2'], **self._label_style)
 
     def _update_view(self):
         for line_name, line_artist in self._line_artists.items():
@@ -124,28 +116,27 @@ class Spec1D(ViewerElement):
         self._update_from_slider()
 
     def reset_view(self):
-        if self._hdu is None:
+        if self._data is None:
             return
 
         self._z_slider.reset()
         self._update_from_slider()
 
-        self._spec_1d.setXRange(*self._default_xrange)
-        self._spec_1d.setYRange(*self._default_yrange)
+        self._spec_1d.setXRange(*self.default_xrange)
+        self._spec_1d.setYRange(*self.default_yrange)
 
     def load_object(self):
         super().load_object()
 
-        del self._hdu
-        del self._default_xrange
-        del self._default_yrange
+        del self.default_xrange
+        del self.default_yrange
         del self._label_height
 
         self._spec_1d.clear()
-        if self._hdu is not None:
+        if self._data is not None:
             self.setEnabled(True)
 
-            self._label.setText("1D spectrum: {}".format(self._filename.name))
+            self._label.setText("{}: {}".format(self.name, self._filename.name))
 
             try:
                 self._z_slider.default_value = self.rd.cat.loc[self.rd.id]['z']
